@@ -117,6 +117,12 @@ sub less_than {
     return $value < $target ? 1 : 0;
 }
 
+sub merge {
+    my ($values) = shift;
+    
+    return [1, join('', @$values)];
+}
+
 sub not_blank   { $_[0] ne '' }
 sub not_defined { !defined $_[0] }
 sub not_space   { $_[0] !~ '^\s*$' ? 1 : 0 }
@@ -207,6 +213,8 @@ Constraint functions is explained in L<Validator::Custom>
 
 =head2 C<less_than>
 
+=head2 C<merge>
+
 =head2 C<not_blank>
 
 =head2 C<not_defined>
